@@ -1,7 +1,7 @@
 
 let re_link = /https?:[^ ]*/
 function hotkey(e) {
-	if (e.ctrlKey || e.altKey)
+	if (e.ctrlKey || e.altKey || e.metaKey)
 		return
 	if (e.code == "Escape") {
 		var menu = document.getElementById("topmenu")
